@@ -3,9 +3,9 @@
 ## Author: Brice Ozenne
 ## Created: mar  3 2022 (12:01) 
 ## Version: 
-## Last-Updated: apr 22 2022 (10:10) 
+## Last-Updated: jul  4 2023 (18:46) 
 ##           By: Brice Ozenne
-##     Update #: 172
+##     Update #: 188
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -23,16 +23,20 @@
 ##' @param data [data.frame] the training data.
 ##' @param name.response [character] The name of the response variable (i.e. the one containing the categories).
 ##' @param type.resampling [character] Should non-parametric bootstrap (\code{"bootstrap"}) or permutation of the outcome (\code{"permutation"}) be used.
-##' @param n.resampling [integer,>0] Nnumber of bootstrap samples or permutations.
+##' @param n.resampling [integer,>0] Number of bootstrap samples or permutations.
 ##' @param fold.repetition [integer,>0] Nnumber of folds used in the cross-validation. Should be strictly positive.
 ##' @param conf.level [numeric, 0-1] confidence level for the confidence intervals.
 ##' @param cpus [integer, >0] the number of CPU to use. If strictly greater than 1, resampling is perform in parallel. 
-##' @param seed [integer, >0] seed used to ensure reproducibility.
+##' @param seed [integer, >0] Random number generator (RNG) state used when starting resampling.
+##' If \code{NULL} no state is set.
 ##' @param trace [logical] Should the execution of the function be traced.
 ##' @param filename [character] Prefix for the files containing each result.
 ##' @param ... arguments passed to \code{\link{performance}}.
 ##'
 ##' @details WARNING: using bootstrap after cross-validation may not provide valid variance/CI/p-value estimates.
+##' 
+##' @return An S3 object of class \code{performance}.
+##' @keywords htest
 
 ## * performanceResample (code)
 ##' @export
@@ -40,17 +44,6 @@ performanceResample <- function(object, data = NULL, name.response = NULL,
                                 type.resampling = "permutation", n.resampling = 1000, fold.repetition = 0, conf.level = 0.95,
                                 cpus = 1, seed = NULL, trace = TRUE, filename = NULL, ...){
 
-    ## ** fix randomness
-    if(!is.null(seed)){
-        if(!is.null(get0(".Random.seed"))){ ## avoid error when .Random.seed do not exists, e.g. fresh R session with no call to RNG
-            old <- .Random.seed # to save the current seed
-            on.exit(.Random.seed <<- old) # restore the current seed (before the call to the function)
-        }else{
-            on.exit(rm(.Random.seed, envir=.GlobalEnv))
-        }
-        set.seed(seed)
-    }
-
     ## ** Normalize arguments
     type.resampling <- match.arg(type.resampling, c("permutation", "bootstrap"))
     if(length(n.resampling)==1){
@@ -60,12 +53,30 @@ performanceResample <- function(object, data = NULL, name.response = NULL,
         n.resampling <- length(vec.resampling)
     }
 
+    ## ** fix randomness
+    if(!is.null(seed)){
+        tol.seed <- 10^(floor(log10(.Machine$integer.max))-1)
+        if(n.resampling>tol.seed){
+            stop("Cannot set a seed per sample when considering more than ",tol.seed," samples. \n")
+        }
+        if(!is.null(get0(".Random.seed"))){ ## avoid error when .Random.seed do not exists, e.g. fresh R session with no call to RNG
+            old <- .Random.seed # to save the current seed
+            on.exit(.Random.seed <<- old) # restore the current seed (before the call to the function)
+        }else{
+            on.exit(rm(.Random.seed, envir=.GlobalEnv))
+        }
+        set.seed(seed)
+        seqSeed <- sample.int(tol.seed, max(vec.resampling),  replace = FALSE) 
+    }else{
+        seqSeed <- NULL
+    }
+
     ## ** Point estimate
     initPerf <- performance(object, data = data, name.response = name.response,
-                            fold.repetition = fold.repetition, se = FALSE, trace = FALSE, seed = NULL, ...)
+                            fold.repetition = fold.repetition, se = FALSE, trace = FALSE, seed = seqSeed[1], ...)
     if(!is.null(filename)){
         if(!is.null(seed)){
-            filename <- paste0(filename,"-seed",seed)
+            filename <- paste0(filename,"-seed",seqSeed[1])
         }
         saveRDS(initPerf, file = paste0(filename,".rds"))
     }
@@ -88,7 +99,7 @@ performanceResample <- function(object, data = NULL, name.response = NULL,
             test.factice <- i %in% vec.resampling == FALSE
             dataResample[[name.response]] <- sample(data[[name.response]])
             iPerf <- try(suppressWarnings(performance(object, data = dataResample, name.response = name.response, fold.repetition = fold.repetition,
-                                                      trace = trace-1, se = FALSE, seed = if(test.factice){"only"}else{NULL}, ...)),
+                                                      trace = trace-1, se = FALSE, seed = seqSeed[iB], ...)),
                          silent = FALSE)
             if(inherits(iPerf, "try-error") || test.factice){
                 return(NULL)
@@ -106,7 +117,7 @@ performanceResample <- function(object, data = NULL, name.response = NULL,
             dataResample <- data[sample(NROW(data), size = NROW(data), replace = TRUE),,drop=FALSE]
             attr(dataResample,"internal") <- attr(data,"internal") ## only do CV
             iPerf <- try(suppressWarnings(performance(object, data = dataResample, name.response = name.response, fold.repetition = fold.repetition,
-                                                      trace = trace-1, se = FALSE, seed = if(test.factice){"only"}else{NULL}, ...)),
+                                                      trace = trace-1, se = FALSE, seed = seqSeed[iB], ...)),
                          silent = FALSE)
             if(inherits(iPerf, "try-error") || test.factice){
                 return(NULL)
@@ -137,19 +148,22 @@ performanceResample <- function(object, data = NULL, name.response = NULL,
                                              FUN = warperResampling)
                                  )
 
-        if(!is.null(seed)){rm(.Random.seed, envir=.GlobalEnv)} # restaure original seed
-
     }else{ ## parallel calculations
         ## define cluster
+        cl <- parallel::makeCluster(cpus)
         if(trace>0){
-            cl <- suppressMessages(parallel::makeCluster(cpus, outfile = ""))
             pb <- utils::txtProgressBar(max = max(vec.resampling), style = 3)          
+            progress <- function(n){utils::setTxtProgressBar(pb, n)}
+            opts <- list(progress = progress)
         }else{
-            cl <- parallel::makeCluster(cpus)
+            opts <- list()
         }
         ## link to foreach
-        doParallel::registerDoParallel(cl)
-
+        doSNOW::registerDoSNOW(cl)
+        ## seed
+        if (!is.null(seed)) {
+            parallel::clusterExport(cl, varlist = "seqSeed", envir = environment())
+        }         
         ## export package
         parallel::clusterCall(cl, fun = function(x){
             suppressPackageStartupMessages(library(BuyseTest, quietly = TRUE, warn.conflicts = FALSE, verbose = FALSE))
@@ -159,13 +173,11 @@ performanceResample <- function(object, data = NULL, name.response = NULL,
         ls.resampling <- foreach::`%dopar%`(
                                       foreach::foreach(iB=1:max(vec.resampling),
                                                        .export = toExport,
-                                                       .packages = "data.table"),                                            
+                                                       .packages = "data.table",
+                                                       .options.snow = opts),                                            
                                       {                                           
-                                          if(trace>0){utils::setTxtProgressBar(pb, iB)}
-
-                                           return(warperResampling(iB))
-                      
-                                       })
+                                          return(warperResampling(iB))
+                                      })
 
         parallel::stopCluster(cl)
         if(trace>0){close(pb)}
